*株式会社ライトストーン
*Stata分析機能例題集　選択モデル

***************係数の解釈***************

*データセットをインポート
use https://www.stata-press.com/data/r16/travel, clear

*合計移動時間を表す時間変数timeを作成
generate time = traveltime+termtime

*選択モデルのデータであることを宣言
cmset id mode

*条件付きロジスティック回帰モデルをフィット
cmclogit choice time, casevars(income partysize)



************マージンからの推論************

***予想される選択確率　―　飛行機を選択する人の割合は全体の何パーセントか？***

*平均予測確率を取得
margins


***連続共変量の効果　―　所得の影響はどのようなものか？***

*自動車を選択する確率に対する所得の影響を評価
margins, at(income=(30(10)70)) outcome(car)

*確率をプロット
marginsplot

*確率の違いをテスト
margins, at(income=(30(10)70)) outcome(car) contrast(atcontrast(ar) nowald effects)

*電車を選択する確率に対する所得の影響を評価
margins, at(income=(30(10)70)) outcome(train)

*確率をプロット
marginsplot

*確率の違いをテスト
margins, at(income=(30(10)70)) outcome(train) contrast(atcontrast(ar) nowald effects)

*各交通手段の選択確率が所得によってどのように変化するかを調べる
margins, at(income=(30(10)70))

*結果をグラフ化
marginsplot, noci

*交通手段の選択予想確率の違いを正式にテスト
margins, at(income=30) contrast(outcomejoint)

*所得が$50,000の場合、電車とバスの交通手段を選択する予想確率に違いがあるかを調べる
margins, at(income=50) outcome(bus train) contrast(outcomecontrast(r) nowald effects)


***カテゴリ共変量の影響***

*incomeの四分位数を表す新規変数income_catを作成し、適当なラベルをつける
xtile income_cat = income, nquantiles(4)
label define quartiles 1 "Quartile 1" 2 "Quartile 2" 3 "Quartile 3" 4 "Quartile 4"
label values income_cat quartiles

*income_catに因子変数を示すi.演算子をつけてモデルをフィット
cmclogit choice time, casevars(i.income_cat partysize)

*所得の四分位数ごとに交通手段として電車を選択する予想確率を推定
margins income_cat, outcome(train)

*結果をグラフ化
marginsplot

*隣接する所得の四分位数間で予想される確率の違いをテスト
margins ar.income_cat, outcome(train) contrast(nowald effects)


***選択肢固有の共変量の影響　―　空港での待ち時間が60分増加した場合の影響は？***

*空港での待ち時間が全てのフライトで60分増加した場合
margins, at(time=generate(time+60)) alternative(air)

*元の移動時間と、飛行機での移動時間が60分増加した場合の両方を一度に推定
margins, at(time=generate(time)) at(time=generate(time+60)) alternative(air)

*結果をグラフ化
marginsplot, xdimension(_outcome)

*確率の違いをテスト
margins, at(time=generate(time)) at(time=generate(time+60)) alternative(air) contrast(atcontrast(r) nowald effects)

*新規変数newtimeを作成
generate newtime = time
replace newtime = time+60 if mode==1
replace newtime = time-60 if mode==2

*飛行機の移動時間が60分増加すると同時に、電車の移動時間が60分減少した場合
margins, at(time=generate(time)) at(time=generate(newtime)) alternative(simultaneous)

*結果をグラフ化
marginsplot, xdimension(_outcome)

*確率の違いをテスト
margins, at(time=generate(time)) at(time=generate(newtime)) alternative(simultaneous) contrast(atcontrast(r) nowald effects)

